@@ -14,6 +14,8 @@ def expr_to_text(expr):
         return ' plus '.join(map(expr_to_text, expr.args))
     elif isinstance(expr, Mul):
         return ' times '.join(map(expr_to_text, expr.args))
+    elif isinstance(expr, Equality):
+        return expr_to_text(expr.lhs) + ' equals ' + expr_to_text(expr.rhs)
     elif isinstance(expr, Pow):
         return expr_to_text(expr.base) + ' to the power of ' + expr_to_text(expr.exp)
     elif isinstance(expr, Symbol):
@@ -25,12 +27,13 @@ def expr_to_text(expr):
 
 
 def process_tex_to_text(tex_string):
+    tex_string = tex_string.replace(r'\intertext{', r'')
+    tex_string = tex_string.replace(r'\\[2mm]', r'')
     math_expressions = findall(r'\$(.*?)\$', tex_string)
     for i in math_expressions:
         eng_expr = expr_to_text(parse_latex(i))
         tex_string = tex_string.replace(f'${i}$', eng_expr)
         
-    tex_string_expr = tex_string.replace(r'\intertext{', r'')
     return expr_to_text(parse_latex(tex_string_expr))
     
     
